@@ -1,5 +1,5 @@
-import collections.abc
 import collections
+import collections.abc
 import re
 
 start_ranges = "|".join(
@@ -27,6 +27,26 @@ NameChar = re.compile(r"(\-|\.|[0-9]|\xB7|[\u0300-\u036F]|[\u203F-\u2040])")
 ########################
 
 
+class DataSorter:
+    """
+    Used to sort a map of data depending on it's type
+    """
+
+    def keys_from(self, data):
+        sorted_data = data
+        if not isinstance(data, collections.OrderedDict):
+            sorted_data = sorted(data)
+        return sorted_data
+
+    class always:
+        def keys_from(self, data):
+            return sorted(data)
+
+    class never:
+        def keys_from(self, data):
+            return data
+
+
 class Node(object):
     """
     Represents each tag in the tree
@@ -48,12 +68,19 @@ class Node(object):
     entities = [("&", "&amp;"), ("<", "&lt;"), (">", "&gt;")]
 
     def __init__(
-        self, wrap="", tag="", data=None, iterables_repeat_wrap=True, closed_tags_for=None
+        self,
+        wrap="",
+        tag="",
+        data=None,
+        iterables_repeat_wrap=True,
+        closed_tags_for=None,
+        data_sorter=None,
     ):
         self.tag = self.sanitize_element(tag)
         self.wrap = self.sanitize_element(wrap)
         self.data = data
         self.type = self.determine_type()
+        self.data_sorter = data_sorter if data_sorter is not None else DataSorter()
         self.closed_tags_for = closed_tags_for
         self.iterables_repeat_wrap = iterables_repeat_wrap
 
@@ -142,11 +169,9 @@ class Node(object):
         children = []
 
         if typ == "mapping":
-            sorted_data = data
-            if not isinstance(data, collections.OrderedDict):
-                sorted_data = sorted(data)
+            sorted_keys = self.data_sorter.keys_from(data)
 
-            for key in sorted_data:
+            for key in sorted_keys:
                 item = data[key]
                 children.append(
                     Node(
@@ -155,6 +180,7 @@ class Node(object):
                         item,
                         iterables_repeat_wrap=self.iterables_repeat_wrap,
                         closed_tags_for=self.closed_tags_for,
+                        data_sorter=self.data_sorter,
                     )
                 )
 
@@ -167,6 +193,7 @@ class Node(object):
                         item,
                         iterables_repeat_wrap=self.iterables_repeat_wrap,
                         closed_tags_for=self.closed_tags_for,
+                        data_sorter=self.data_sorter,
                     )
                 )
 
@@ -257,7 +284,7 @@ class Converter(object):
 
         return ret
 
-    def build(self, data, iterables_repeat_wrap=True, closed_tags_for=None):
+    def build(self, data, iterables_repeat_wrap=True, closed_tags_for=None, data_sorter=None):
         """Create a Node tree from the data and return it as a serialized xml string"""
         indenter = self._make_indenter()
         return Node(
@@ -265,4 +292,5 @@ class Converter(object):
             data=data,
             iterables_repeat_wrap=iterables_repeat_wrap,
             closed_tags_for=closed_tags_for,
+            data_sorter=data_sorter,
         ).serialize(indenter)
